from canonmap.models.entity_mapping_request import EntityMappingRequest

class EntityMapper:
    def __init__(self) -> None:
        pass

    def map(self, config: EntityMappingRequest) -> None:
        pass


from typing import List
from pydantic import BaseModel, Field

class EntityMappingRequest(BaseModel):
    entities: List[str] = Field(
        ...,
        description="List of entities to map."
    )
    verbose: bool = Field(
        False,
        description="Enable verbose logging for debugging."
    )